function initEdit(baseUrl, trans) {

    var resultsPerPage = 100,
        multiplier = resultsPerPage < 10 ? 10 / resultsPerPage : 1,
        lastRequestUrl,
        lastData = [],
        needChecking = false,
        checked = [];

// TODO: fix ajaxUrl so it works on dev version and prod version
    var pagerOptions = {
        container: $(".pager"),
        ajaxUrl: baseUrl+"/rest/api/piwik/1.0/spaces?page={page}",
        ajaxProcessing: function(data) {
            if (typeof data.spaces === "undefined") {
                return [0, []];
            }
            var spaces = data.spaces.map(function(space) {return [space.key, JSON.stringify(space), space.name, space.tracked, JSON.stringify(space), JSON.stringify(space)];});

            setLastRequestData(data);

            return [data.results * multiplier, spaces];
        },
        processAjaxOnInit: true,
        output: '{startRow} – {endRow} / {totalRows}',
        page: 0,
        size: resultsPerPage,
        savePages : false,
        storageKey:'tablesorter-pager',
        pageReset: 0,
        removeRows: false,
        updateArrows: true,
        cssNext: '.next',
        cssPrev: '.prev',
        cssFirst: '.first',
        cssLast: '.last',
        cssPageDisplay : '.pagedisplay',
        cssDisabled: 'disabled',
        cssErrorRow: 'tablesorter-errorRow'
    };

     function onCheck() {
        var isChecked = $(this).is(":checked"),
            whatIsChecked = $(this).attr("value");

        if (isChecked) {
            checked.push(whatIsChecked)
        } else {
            checked = checked.filter(function(value) {
                return value !== whatIsChecked;
            });
        }
        checkedElementsStateUpdated();
    };

    function checkedElementsStateUpdated() {
        var $selected = $('.selected-elements');
            $noneSelected = $('.none-selected');

        if (checked.length > 0) {
            $selected
                .removeClass("d-none")
                .find(".elements")
                .html(checked.sort().join(", "));
            $noneSelected.addClass("d-none");
        } else {
            $selected.addClass("d-none");
            $noneSelected.removeClass("d-none");
        }
    }

    function setLastRequestData(data) {
        lastData = data.spaces;
        lastRequestUrl = pagerOptions.ajaxUrl.replace("{page}", data.page);
        needChecking = false;
        for (var k in lastData) {
            if (lastData[k].isProcessing) {
                needChecking = true;
                break;
            }
        }
    }

    setInterval(function() {
        if (!needChecking) {
            return;
        }
        var previousData = lastData;

        AJS.$.ajax({
            url: lastRequestUrl,
            type: "GET",
            contentType: "application/json",
            success: function(data) {
                if (previousData !== lastData) {
                    return;
                }
                for (var k in lastData) {
                    if (lastData[k].isProcessing && !data.spaces[k].isProcessing) {
                        console.log("need reset");
                        $("#piwik-space-mapping").trigger("pagerUpdate");
                        break;
                    }
                }
            }
        });
    }, 2000);

    $(".selected-actions button.track").click(function() {
        var track = $(this).hasClass("untrack") ? "untrack" : "track";

        AJS.$.ajax({
            url: baseUrl+"/rest/api/piwik/1.0/track",
            type: "POST",
            data: JSON.stringify({spaces: checked, type: track}),
            dataType: "json",
            contentType: "application/json",
            success: function() {
                window.location.reload();
            },
            error: function(data) {
                var $error = $("<div class=\"aui-message aui-message-error error closeable\"></div>");
                console.log(data);
                if (data.responseJSON && data.responseJSON.message) {
                    AJS.messages.error('.error-container',{
                        title: data.responseJSON.message
                    });
                }
            }
        })
    });

    $('.selected-actions button.select-all').click(function() {
        var isSelectAll = !$(this).hasClass("unselect-all");

         $('table.tablesorter input[type=checkbox]').each(function() {
            var $input = $(this);

            if ((isSelectAll && $input.is(":not(:checked)")) || (!isSelectAll && $input.is(":checked"))) {
                $input.click();
            }
         });
    });

    jQuery.tablesorter.addParser({
        id: 'data',
        is: function() {
            return false;
        },
        format: function(s, table, cell, cellIndex) {
            var $cell = $(cell);
            if (cellIndex === 0) {
                var isChecked = checked.indexOf(s) !== -1;

                $cell.html("<input type='checkbox' name='key' value='"+s+"'"+(isChecked ? " checked" : "")+"/>");
                $cell.find("input").on('change', onCheck)
            }
            if (cellIndex === 1) {
                var space = JSON.parse(s),
                    text = space.key;

                $cell.html(text + (space.archived ? " <span class=\"smalltext\">" + trans.archived + "</span>":''));
                $cell.wrapInner("<strong></strong>");
            }
            if (cellIndex === 4) {
                var space = JSON.parse(s),
                    $element = $("<span>" + (space.websiteName || "" )+"</span>");

                if (space.tracked) {
                    $element.wrapInner("<a href=\""+space.dashboardUrl+"\" target=\"_blank\"></a>");
                }
                $cell.html($element);
            }
            if (cellIndex === 5) {
                var space = JSON.parse(s),
                    $spinner = $("<aui-spinner size=\"small\" style=\"display: inline-block\"></aui-spinner>"),
                    $track = $("<a href=\"piwiktrackspace.action?space=" + space.key + "\">"+trans.track+"</a>"),
                    $edit = $("<a href=\"editpiwikspace.action?space=" + space.key + "#" + trans.urlCSRF +"\">"+trans.edit+"</a>")
                    $error = $("<span class=\"aui-icon aui-icon-small aui-iconfont-error\">" + trans.error + "</span>");

                    if (space.tracked) {
                        $track = $("<a href=\"piwikuntrackspace.action?space=" + space.key + "\">"+trans.untrack+"</a>");
                    }
                    $cell.html("").append($track).append("&middot;").append($edit);
                    if (space.isProcessing) {
                        $cell.append("&middot;").append($spinner);
                    }
                    if (space.error && space.error.length > 0) {
                        $error.attr("title", space.error);
                        $cell.append("&middot;").append($error);
                        AJS.$($error).tooltip();
                    }
                    $cell.wrapInner("<div style='display:flex;gap:5px'></div>")
            }
        },
        parsed: false,
        type: 'text'
    });
    $('.sync-spaces').click(function() {
        var that = this;
        that.busy();
        AJS.$.ajax({
            url: "piwiksyncspaces.action",
            type: "GET",
            success: function(data) {
                that.idle();
                window.location.reload();
            }
        });
    });

   $("#piwik-space-mapping").tablesorter({
           headers: {
               '.all': {sorter: 'data'}
           }
   }).tablesorterPager(pagerOptions);

}
